@@ -300,7 +300,9 @@ def add_embeddings_to_index_distributed(
     n_workers = len(sc.statusTracker().getExecutorInfos()) - 1
 
     # maximum between the number of spark workers, 10M embeddings per task and the number of indices to keep
-    estimated_nb_batches = max(n_workers, math.ceil(embedding_reader.count / (10 ** 7)), nb_indices_to_keep)
+    estimated_nb_batches = min(
+        embedding_reader.count, max(n_workers, math.ceil(embedding_reader.count / (10 ** 7)), nb_indices_to_keep)
+    )
     batches = _batch_loader(total_size=embedding_reader.count, nb_batches=estimated_nb_batches)
     rdd = ss.sparkContext.parallelize(batches, estimated_nb_batches)
     with Timeit("-> Adding indices", indent=2):
